import { setSessionId, setToken } from "@/auth/auth";
import { Role } from "@/types";
import { defineStore } from "pinia";

// main is the name of the store. It is unique across your application
// and will appear in devtools
export const useMainStore = defineStore("main", {
  // a function that returns a fresh state
  state: () => {
    return {
      globalMask: false,
      userInfo: {
        userId: -1,
        identity: "",
        displayName: "",
        rootOrgId: -1,
        rootOrgName: "",
        token: "",
        roleList: [] as Role[],
      },
      currentLocation: "",
    };
  },
  getters: {
    isSuperAdmin(): boolean {
      return this.userInfo.roleList.some((r) => r.roleCode === "SUPER_ADMIN");
    },
    isRootOrgAdmin(): boolean {
      return this.userInfo.roleList.some(
        (r) => r.roleCode === "ROOT_ORG_ADMIN"
      );
    },
    isOrgAdmin(): boolean {
      return this.userInfo.roleList.some((r) => r.roleCode === "ORG_ADMIN");
    },
    isGreaterThanEqualRootOrgAdmin(): boolean {
      return (
        this.userInfo.roleList.some((r) => r.roleCode === "SUPER_ADMIN") ||
        this.userInfo.roleList.some((r) => r.roleCode === "ROOT_ORG_ADMIN")
      );
    },
    isGreaterThanEqualOrgAdmin(): boolean {
      return (
        this.userInfo.roleList.some((r) => r.roleCode === "SUPER_ADMIN") ||
        this.userInfo.roleList.some((r) => r.roleCode === "ROOT_ORG_ADMIN") ||
        this.userInfo.roleList.some((r) => r.roleCode === "ORG_ADMIN")
      );
    },
  },
  actions: {
    setUserInfo(res: any) {
      this.userInfo = res;
      setToken(this.userInfo.token);
      setSessionId(this.userInfo.identity);
    },
  },
});

setTimeout(() => {
  const store = useMainStore();
  store.$subscribe((_, state) =>
    sessionStorage.setItem("appState", JSON.stringify(state))
  );
  const state = JSON.parse(
    sessionStorage.getItem("appState") || "{}"
  ) as ReturnType<typeof useMainStore>;
  if (state.userInfo?.token) {
    Object.assign(store, state);
  }
}, 0);
