import { defineConfig } from "vite";
import vue from "@vitejs/plugin-vue";
import ViteComponents from "unplugin-vue-components/vite";
import { AntDesignVueResolver } from "unplugin-vue-components/resolvers";
import AutoImport from "unplugin-auto-import/vite";

const SERVER_URL = "http://192.168.10.39:8081";
const path = require("path");

// https://vitejs.dev/config/
export default defineConfig({
  plugins: [
    vue({
      refTransform: true,
    }),
    ViteComponents({
      resolvers: [AntDesignVueResolver()],
      dts: true,
    }),
    AutoImport({
      // targets to transform
      include: [
        /\.[tj]sx?$/, // .ts, .tsx, .js, .jsx
        /\.vue\??/, // .vue
      ],
      // global imports to register
      imports: [
        // presets
        "vue",
        "vue-router",
      ],
    }),
  ],
  server: {
    port: 9000,
    // strictPort: true,
    fs: {
      strict: true,
      allow: ["./"],
    },
    proxy: {
      "/api": {
        target: SERVER_URL,
        changeOrigin: true,
      },
    },
  },
  resolve: {
    alias: [{ find: "@", replacement: path.resolve(__dirname, "./src") }],
    extensions: [".js", ".mjs", ".ts", ".vue", ".json", ".scss", ".css"],
  },
  build: {
    ssr: false,
  },
  // define: {
  //   __VUE_PROD_DEVTOOLS__: true, // no effect
  // },
});
